@@ -537,8 +537,8 @@ sub todo_tests_default {
     my $DEBUGGING = ($Config{ccflags} =~ m/-DDEBUGGING/);
     my $ITHREADS  = ($Config{useithreads});
 
-    my @todo  = (35,41..44,46); # 8,14-16 fail on 5.00505 (max 20 then)
-    push @todo, (15) if !$ITHREADS;
+    my @todo  = (15,35,41..46); # 8,14-16 fail on 5.00505 (max 20 then)
+    #push @todo, (15) if !$ITHREADS;
     # 15 passes on cygwin XP, but fails on cygwin Win7
     if ($what =~ /^c(|_o[1-4])$/) {
         # 14+23 fixed with 1.04_29, for 5.10 with 1.04_31
@@ -547,33 +547,30 @@ sub todo_tests_default {
         # 5.8.8 CORE: 11,14,15,20,23 / non-threaded: 5,7-12,14-20,22-23,25
         # @todo = (15,35,39,44,46)    if $] < 5.010;
         push @todo, (103)  if $] < 5.007;
-        push @todo, (45)   if $what ne 'c' and $] < 5.007;
+        #push @todo, (45)   if $what ne 'c' and $] < 5.007;
         push @todo, (39)   if $] > 5.007 and $] < 5.009;
         push @todo, (103)  if $] >= 5.010;
-        push @todo, (28)   if $what eq 'c';
-        push @todo, (16)   if $] > 5.013;
-        #push @todo, (29)   if $what eq 'c_o1' and $DEBUGGING;
-        push @todo, (12)   if $what eq 'c_o2';
+        push @todo, (28)   if $what ne 'c_o1';
+        push @todo, (12)   if $what =~ /c_o[234]/;
         push @todo, (19)   if $what eq 'c_o2' and $ITHREADS;
-        #push @todo, (17..20,22,34..41) if $what =~ 'c_o2';
-        #push @todo, (26) if $what eq 'c_o1' and $] < 5.010;
-	#push @todo, (10..12,28) if $what =~ /c_o[234]/ and $] >= 5.010;
-	#push @todo, (25) if $what eq 'c_o' and $^O eq 'MSWin32';
+	push @todo, (29)   if $what =~ /c_o[1234]/ and $] >= 5.010;
 	push @todo, (10,12,19,25) if $what eq 'c_o4';
     } elsif ($what =~ /^cc/) {
         # 8,11,14..16,18..19 fail on 5.00505 + 5.6, old core failures (max 20)
         # on cygwin 29 passes
-        push @todo, (15,21,30,45,103); #5.8.9
-        #push @todo, (27)    if $] < 5.007;
-        push @todo, (39)   if $] > 5.007 and $] < 5.009;
+        push @todo, (15,21,29,30,45); #5.8.9
+        #push @todo, (27)   if $] < 5.007;
+        push @todo, (39)    if $] > 5.007 and $] < 5.009;
         #push @todo, (11,27) if $] < 5.009;
-        push @todo, (14)    if $] >= 5.010;
+        push @todo, (14)    if $] >= 5.010 and $^O !~ /MSWin32|cygwin/i;
         # solaris also. I suspected nvx<=>cop_seq_*
         push @todo, (12)    if $^O eq 'MSWin32' and $Config{cc} =~ /^cl/i;
         #push @todo, (3,4,27,42,43) if $] >= 5.011004 and $ITHREADS;
-        push @todo, (10,16) if $what eq 'cc_o2';
+        push @todo, (10,16,27) if $what eq 'cc_o2';
         push @todo, (26)    if $what =~ /^cc_o[12]/;
+        push @todo, (3,4)   if $] >= 5.012 and $ITHREADS;
     }
+    push @todo, (25)   if $] >= 5.010 and $] < 5.012 and !$ITHREADS;
     #push @todo, (32)       if $] >= 5.011003;
     return @todo;
 }
